﻿using DamageAssesment.Api.Surveys.Interfaces;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;

namespace DamageAssesment.Api.Surveys.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class SurveysController : ControllerBase
    {
        private ISurveyProvider surveyProvider;

        public SurveysController(ISurveyProvider surveyProvider)
        {
            this.surveyProvider = surveyProvider;
        }
        /// <summary>
        /// GET request for retrieving surveys.
        /// </summary>

        [HttpGet]
        public async Task<ActionResult> GetSurveysAsync()
        {
            var result = await this.surveyProvider.GetSurveysAsync();
            if (result.IsSuccess)
            {
                return Ok(result.Surveys);
            }
            return NoContent();
        }
        /// <summary>
        /// GET request for retrieving surveys by ID.
        /// </summary>

        [HttpGet("{Id}")]
        public async Task<ActionResult> GetSurveysAsync(int Id)
        {
            var result = await this.surveyProvider.GetSurveysAsync(Id);
            if (result.IsSuccess)
            {
                return Ok(result.Surveys);
            }
            return NotFound();
        }
        /// <summary>
        /// POST request for creating a new survey.
        /// </summary>

        [HttpPost]
        public async Task<ActionResult> PostSurveysAsync(Models.Survey survey)
        {
            var result = await this.surveyProvider.PostSurveyAsync(survey);
            if (result.IsSuccess)
            {
                return Ok(result.Survey);
            }
            return BadRequest(result.ErrorMessage);
        }
        /// <summary>
        /// PUT request for updating an existing survey (surveyId,Updated Survey data).
        /// </summary>
       

        [HttpPut("{Id}")]
        public async Task<ActionResult> PutSurveysAsync(int Id, Models.Survey survey)
        {
            var result = await this.surveyProvider.PutSurveyAsync(Id,survey);
            if (result.IsSuccess)
            {
                return Ok(result.Survey);
            }
            if (result.ErrorMessage == "Not Found")
                return NotFound(result.ErrorMessage);
            
            return BadRequest(result.ErrorMessage);
        }
        /// <summary>
        /// DELETE request for deleting a survey by ID.
        /// </summary>
       
        [HttpDelete("{Id}")]
        public async Task<ActionResult> DeleteSurveysAsync(int Id)
        {
            var result = await this.surveyProvider.DeleteSurveyAsync(Id);
            if (result.IsSuccess)
            {
                return Ok(result.Survey);
            }
            return NotFound();
        }
    }
}
